==> libuhd-docs-4.9.0.1-2-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/search/all_10.js <==
var searchData=
[
  ['ha_0',['HA',['../page_rdtesting.html#autotoc_md34',1,'']]],
  ['handles_1',['C-Level Handles',['../page_c_api.html#c_api_handles',1,'']]],
  ['handling_2',['Handling',['../classuhd_1_1rfnoc_1_1replay__block__control.html#rfnoc_block_replay_actions',1,'Action Handling'],['../classuhd_1_1rx__streamer.html#stream_rx_error_handling',1,'Error Handling'],['../classuhd_1_1rfnoc_1_1radio__control.html#rfnoc_radio_overrun_handling',1,'Overrun Handling'],['../page_usrp_b200.html#care_and_handling',1,'Proper Care and Handling'],['../page_usrp_x4xx.html#x4xx_getting_started_handling',1,'Proper Care and Handling']]],
  ['handling_20unknown_20properties_3',['Handling unknown properties',['../page_properties.html#props_unknown',1,'']]],
  ['hardware_20console_4',['Launch Vivado Hardware Console',['../md_usrp3_2vivado__env__utils.html#autotoc_md250',1,'']]],
  ['hardware_20management_5',['Hardware Management',['../md_usrp3_2vivado__env__utils.html#autotoc_md249',1,'']]],
  ['hardware_20notes_6',['Hardware Notes',['../page_usrp_x3x0.html#x3x0_hw_notes',1,'']]],
  ['hardware_20reference_7',['Hardware Reference',['../page_usrp_b200.html#b200_hw_ref',1,'']]],
  ['hardware_20resources_8',['Hardware Resources',['../page_usrp_b200.html#b200_hardware',1,'']]],
  ['hardware_20selection_9',['Host PC Hardware Selection',['../page_usrp_x3x0_config.html#x3x0cfg_hosthw',1,'']]],
  ['hardware_20setup_10',['Hardware Setup',['../page_usrp_x3x0.html#x3x0_hw',1,'']]],
  ['hardware_20setup_20notes_11',['Hardware Setup Notes',['../page_usrp1.html#usrp1_hw',1,'Hardware Setup Notes'],['../page_usrp2.html#usrp2_hw',1,'Hardware Setup Notes'],['../page_usrp_e1x0.html#e1x0_hw',1,'Hardware Setup Notes']]],
  ['hardware_20setup_20notes_12',['Hardware setup notes',['../page_usrp_b100.html#b100_hw',1,'']]],
  ['hardware_20specific_20converters_13',['Hardware-specific Converters',['../page_converters.html#converters_accel',1,'']]],
  ['has_14',['has',['../namespaceuhd.html#a42e26d89ae5d0ad803137f6dd9515581',1,'uhd']]],
  ['has_5fblock_15',['has_block',['../classuhd_1_1rfnoc_1_1rfnoc__graph.html#a9e24d75205a93e020a4de37f3cbfb58a',1,'uhd::rfnoc::rfnoc_graph::has_block(const block_id_t &amp;block_id) const =0'],['../classuhd_1_1rfnoc_1_1rfnoc__graph.html#a15c34730278dea8eb0c0f0d0fca1fea8',1,'uhd::rfnoc::rfnoc_graph::has_block(const block_id_t &amp;block_id) const']]],
  ['has_5fcal_5fdata_16',['has_cal_data',['../classuhd_1_1usrp_1_1cal_1_1database.html#a5605b43f778efc10f29cb616afbfb7d9',1,'uhd::usrp::cal::database']]],
  ['has_5fcid_17',['has_cid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#abf03386fd2cfaa59b3948645ad9ceb36',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5fdata_5ffn_5ftype_18',['has_data_fn_type',['../classuhd_1_1usrp_1_1cal_1_1database.html#ac829f93eea5131a0bf30f91084066eea',1,'uhd::usrp::cal::database']]],
  ['has_5ffeature_19',['has_feature',['../classuhd_1_1features_1_1discoverable__feature__getter__iface.html#a3c10404e4df102e54f874eccc2448612',1,'uhd::features::discoverable_feature_getter_iface']]],
  ['has_5fkey_20',['has_key',['../classuhd_1_1dict.html#ab4cd0c4ab3926a7eb19194e245771451',1,'uhd::dict']]],
  ['has_5fread_5fcallback_21',['has_read_callback',['../classuhd_1_1experts_1_1dag__vertex__t.html#a1e4052db7c1f57a830ba56b80a271e5d',1,'uhd::experts::dag_vertex_t']]],
  ['has_5frx_5fpower_5freference_22',['has_rx_power_reference',['../classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface.html#a868fc9fb2321c1e42717fb7886f1d2b0',1,'uhd::rfnoc::rf_control::power_reference_iface::has_rx_power_reference()'],['../classuhd_1_1usrp_1_1multi__usrp.html#af0307aa83d1454e92a7ec91fb4100b98',1,'uhd::usrp::multi_usrp::has_rx_power_reference()']]],
  ['has_5fset_5ffe_5fconnection_23',['has_set_fe_connection',['../classuhd_1_1usrp_1_1dboard__iface.html#aa6e8cc93ab3dc932e746ea5d45553049',1,'uhd::usrp::dboard_iface']]],
  ['has_5fsid_24',['has_sid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a8415dcafcf5b32750a757b5b15424aad',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftime_5fspec_25',['has_time_spec',['../structuhd_1_1rx__metadata__t.html#a7cd978c6290c12f3bb92072286109123',1,'uhd::rx_metadata_t::has_time_spec'],['../structuhd_1_1tx__metadata__t.html#af8f34976fc468381bfc662f57a398360',1,'uhd::tx_metadata_t::has_time_spec'],['../structuhd_1_1async__metadata__t.html#a333d1558d0bf0621f4476fcab2e8a269',1,'uhd::async_metadata_t::has_time_spec']]],
  ['has_5ftimestamp_26',['has_timestamp',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a168a2dc1e766faefe60b64389f9cca90',1,'uhd::rfnoc::chdr::ctrl_payload']]],
  ['has_5ftlr_27',['has_tlr',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#aae2d1fc554402f5eda38879578af0add',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftsf_28',['has_tsf',['../structuhd_1_1rfnoc_1_1tx__event__action__info.html#a7621de07341c51598b8a0954ec094ec3',1,'uhd::rfnoc::tx_event_action_info::has_tsf'],['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a05620235be16ac3b9ad1eaf0864d6627',1,'uhd::transport::vrt::if_packet_info_t::has_tsf']]],
  ['has_5ftsi_29',['has_tsi',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a9dcd8f46d3f39627945dd9d429fec8a3',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftx_5fpower_5freference_30',['has_tx_power_reference',['../classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface.html#a3566202d0e04760394a9881e49f6c142',1,'uhd::rfnoc::rf_control::power_reference_iface::has_tx_power_reference()'],['../classuhd_1_1usrp_1_1multi__usrp.html#af5384b36f4fe1f8f90b41d8632c85ada',1,'uhd::usrp::multi_usrp::has_tx_power_reference()']]],
  ['has_5fwrite_5fcallback_31',['has_write_callback',['../classuhd_1_1experts_1_1dag__vertex__t.html#a6ff77d1929aee5558be2a68c607396aa',1,'uhd::experts::dag_vertex_t']]],
  ['have_32',['have',['../md_usrp2_2build__instructions.html#autotoc_md98',1,'What FPGA does my USRP have?'],['../md_usrp3_2build__instructions.html#autotoc_md111',1,'What FPGA does my USRP have?']]],
  ['have_20an_20equality_20operator_33',['- Must have an equality operator (==)',['../classuhd_1_1experts_1_1data__node__t.html#autotoc_md255',1,'']]],
  ['heterodyne_34',['HETERODYNE',['../classuhd_1_1usrp_1_1fe__connection__t.html#aadf0572b3c622e61053ed405327ec61fa9eed1d12ba57e1b4b6737a9f3c74513b',1,'uhd::usrp::fe_connection_t']]],
  ['hexstr_5fcast_35',['hexstr_cast',['../namespaceuhd_1_1cast.html#aa2744fe5ab41766361099fa0c9de22ce',1,'uhd::cast']]],
  ['hg_36',['HG',['../page_rdtesting.html#autotoc_md29',1,'HG'],['../page_rdtesting.html#autotoc_md32',1,'HG'],['../page_rdtesting.html#autotoc_md38',1,'HG']]],
  ['high_37',['HIGH',['../namespaceuhd_1_1usrp_1_1zbx.html#af1259db5d00c9426221fc97835c38a4ea8cbb5e15e59883ec9df14738fe49a539',1,'uhd::usrp::zbx']]],
  ['high_20level_3a_20the_20c_20api_38',['High-Level: The C API',['../page_coding.html#coding_api_hilevelc',1,'']]],
  ['high_20level_3a_20the_20multi_20usrp_39',['High-Level: The Multi-USRP',['../page_coding.html#coding_api_hilevel',1,'']]],
  ['high_20level_3a_20the_20multi_20usrp_20clock_40',['High-Level: The Multi-USRP-Clock',['../page_coding.html#coding_api_hilevelclock',1,'']]],
  ['high_20level_3a_20the_20rfnoc_20api_41',['High-Level: The RFNoC API',['../page_coding.html#coding_api_hilevel_rfnoc',1,'']]],
  ['hijack_20mode_42',['Hijack Mode',['../page_mpm.html#mpm_shell_hijack',1,'']]],
  ['hops_5fto_5fstring_43',['hops_to_string',['../classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload.html#a8fd2de17a81e6fb976e2984607e69baf',1,'uhd::rfnoc::chdr::mgmt_payload']]],
  ['host_44',['host',['../page_usrp2.html#usrp2_network_multidev',1,'Multiple devices per host'],['../page_usrp_x3x0.html#x3x0_setup_network_multidevs',1,'Multiple devices per host']]],
  ['host_20computer_45',['Host Computer',['../page_usrp_b200.html#connect_device',1,'Connect the USRP to the Host Computer'],['../page_usrp_b200.html#install_software_tools',1,'Install and Setup the Software Tools on Your Host Computer'],['../page_usrp_x4xx.html#x4xx_getting_started_install_uhd_host',1,'Installing UHD on the Host Computer']]],
  ['host_20cpu_20data_20type_46',['The host/CPU data type',['../page_stream.html#stream_datatypes_cpu',1,'']]],
  ['host_20ethernet_20interface_47',['Installing the Host Ethernet Interface',['../page_usrp_x3x0.html#autotoc_md58',1,'']]],
  ['host_20interface_48',['host interface',['../page_usrp2.html#usrp2_network_setuphost',1,'Setup the host interface'],['../page_usrp_x3x0.html#x3x0_setup_network_host_interface',1,'Setup the host interface']]],
  ['host_20network_20traffic_49',['host network traffic',['../page_usrp2.html#usrp2_commprob_wireshark',1,'Monitor the host network traffic'],['../page_usrp_x3x0.html#x3x0_comm_issues_monitor',1,'Monitor the host network traffic']]],
  ['host_20operating_20system_50',['The RFSoC CPU/FPGA and Host Operating System',['../page_usrp_x4xx.html#x4xx_overview_rfsoc',1,'']]],
  ['host_20operating_20system_51',['host operating system',['../page_usrp_e3xx.html#e310_zynq',1,'The Zynq CPU/FPGA and host operating system'],['../page_usrp_e3xx.html#e320_zynq',1,'The Zynq CPU/FPGA and host operating system'],['../page_usrp_n3xx.html#n3xx_zynq',1,'The Zynq CPU/FPGA and host operating system']]],
  ['host_20pc_52',['Configuring your Host PC',['../page_usrp_x3x0_config.html#x3x0cfg_hostpc',1,'']]],
  ['host_20pc_20hardware_20selection_53',['Host PC Hardware Selection',['../page_usrp_x3x0_config.html#x3x0cfg_hosthw',1,'']]],
  ['host_20s_20ip_20address_54',['Configuring the host&apos;s IP address',['../page_usrp_x3x0_config.html#x3x0cfg_hostpc_netcfg_ip',1,'']]],
  ['hot_20plugging_20and_20power_20cycling_55',['Hot-Plugging and Power-Cycling',['../page_ni_rio_kernel.html#linux_swapping',1,'']]],
  ['hot_20plugging_20and_20power_20cycling_56',['Hot-plugging and Power-cycling',['../page_ni_rio_kernel.html#win_swapping',1,'']]],
  ['how_20to_20use_20the_20extension_20framework_57',['How to use the Extension Framework',['../page_extension.html#extension_howto',1,'']]],
  ['htonx_58',['htonx',['../namespaceuhd.html#ae5e5910558275e7c986e041e1f8fe1f5',1,'uhd::htonx(T)'],['../namespaceuhd.html#a7dfebe1a8443034fcc541a77afa24e31',1,'uhd::htonx(T num)']]],
  ['htowx_59',['htowx',['../namespaceuhd.html#a66d493f4be1a88fd6bb25c9914142343',1,'uhd::htowx(T)'],['../namespaceuhd.html#a0a543a320de74e9ed2fe4c51c684cf42',1,'uhd::htowx(T num)']]]
];

==> libuhd-docs-4.9.0.1-3-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/search/all_10.js <==
var searchData=
[
  ['ha_0',['HA',['../page_rdtesting.html#autotoc_md34',1,'']]],
  ['handles_1',['C-Level Handles',['../page_c_api.html#c_api_handles',1,'']]],
  ['handling_2',['Handling',['../classuhd_1_1rfnoc_1_1replay__block__control.html#rfnoc_block_replay_actions',1,'Action Handling'],['../classuhd_1_1rx__streamer.html#stream_rx_error_handling',1,'Error Handling'],['../classuhd_1_1rfnoc_1_1radio__control.html#rfnoc_radio_overrun_handling',1,'Overrun Handling'],['../page_usrp_b200.html#care_and_handling',1,'Proper Care and Handling']]],
  ['handling_20unknown_20properties_3',['Handling unknown properties',['../page_properties.html#props_unknown',1,'']]],
  ['hardware_20console_4',['Launch Vivado Hardware Console',['../md_usrp3_2vivado__env__utils.html#autotoc_md249',1,'']]],
  ['hardware_20management_5',['Hardware Management',['../md_usrp3_2vivado__env__utils.html#autotoc_md248',1,'']]],
  ['hardware_20notes_6',['Hardware Notes',['../page_usrp_x3x0.html#x3x0_hw_notes',1,'']]],
  ['hardware_20reference_7',['Hardware Reference',['../page_usrp_b200.html#b200_hw_ref',1,'']]],
  ['hardware_20resources_8',['Hardware Resources',['../page_usrp_b200.html#b200_hardware',1,'']]],
  ['hardware_20selection_9',['Host PC Hardware Selection',['../page_usrp_x3x0_config.html#x3x0cfg_hosthw',1,'']]],
  ['hardware_20setup_10',['Hardware Setup',['../page_usrp_x3x0.html#x3x0_hw',1,'']]],
  ['hardware_20setup_20notes_11',['Hardware Setup Notes',['../page_usrp1.html#usrp1_hw',1,'Hardware Setup Notes'],['../page_usrp2.html#usrp2_hw',1,'Hardware Setup Notes'],['../page_usrp_e1x0.html#e1x0_hw',1,'Hardware Setup Notes']]],
  ['hardware_20setup_20notes_12',['Hardware setup notes',['../page_usrp_b100.html#b100_hw',1,'']]],
  ['hardware_20specific_20converters_13',['Hardware-specific Converters',['../page_converters.html#converters_accel',1,'']]],
  ['has_14',['has',['../namespaceuhd.html#a42e26d89ae5d0ad803137f6dd9515581',1,'uhd']]],
  ['has_5fblock_15',['has_block',['../classuhd_1_1rfnoc_1_1rfnoc__graph.html#a9e24d75205a93e020a4de37f3cbfb58a',1,'uhd::rfnoc::rfnoc_graph::has_block(const block_id_t &amp;block_id) const =0'],['../classuhd_1_1rfnoc_1_1rfnoc__graph.html#a15c34730278dea8eb0c0f0d0fca1fea8',1,'uhd::rfnoc::rfnoc_graph::has_block(const block_id_t &amp;block_id) const']]],
  ['has_5fcal_5fdata_16',['has_cal_data',['../classuhd_1_1usrp_1_1cal_1_1database.html#a5605b43f778efc10f29cb616afbfb7d9',1,'uhd::usrp::cal::database']]],
  ['has_5fcid_17',['has_cid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#abf03386fd2cfaa59b3948645ad9ceb36',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5fdata_5ffn_5ftype_18',['has_data_fn_type',['../classuhd_1_1usrp_1_1cal_1_1database.html#ac829f93eea5131a0bf30f91084066eea',1,'uhd::usrp::cal::database']]],
  ['has_5ffeature_19',['has_feature',['../classuhd_1_1features_1_1discoverable__feature__getter__iface.html#a3c10404e4df102e54f874eccc2448612',1,'uhd::features::discoverable_feature_getter_iface']]],
  ['has_5fkey_20',['has_key',['../classuhd_1_1dict.html#ab4cd0c4ab3926a7eb19194e245771451',1,'uhd::dict']]],
  ['has_5fread_5fcallback_21',['has_read_callback',['../classuhd_1_1experts_1_1dag__vertex__t.html#a1e4052db7c1f57a830ba56b80a271e5d',1,'uhd::experts::dag_vertex_t']]],
  ['has_5frx_5fpower_5freference_22',['has_rx_power_reference',['../classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface.html#a868fc9fb2321c1e42717fb7886f1d2b0',1,'uhd::rfnoc::rf_control::power_reference_iface::has_rx_power_reference()'],['../classuhd_1_1usrp_1_1multi__usrp.html#af0307aa83d1454e92a7ec91fb4100b98',1,'uhd::usrp::multi_usrp::has_rx_power_reference()']]],
  ['has_5fset_5ffe_5fconnection_23',['has_set_fe_connection',['../classuhd_1_1usrp_1_1dboard__iface.html#aa6e8cc93ab3dc932e746ea5d45553049',1,'uhd::usrp::dboard_iface']]],
  ['has_5fsid_24',['has_sid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a8415dcafcf5b32750a757b5b15424aad',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftime_5fspec_25',['has_time_spec',['../structuhd_1_1rx__metadata__t.html#a7cd978c6290c12f3bb92072286109123',1,'uhd::rx_metadata_t::has_time_spec'],['../structuhd_1_1tx__metadata__t.html#af8f34976fc468381bfc662f57a398360',1,'uhd::tx_metadata_t::has_time_spec'],['../structuhd_1_1async__metadata__t.html#a333d1558d0bf0621f4476fcab2e8a269',1,'uhd::async_metadata_t::has_time_spec']]],
  ['has_5ftimestamp_26',['has_timestamp',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a168a2dc1e766faefe60b64389f9cca90',1,'uhd::rfnoc::chdr::ctrl_payload']]],
  ['has_5ftlr_27',['has_tlr',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#aae2d1fc554402f5eda38879578af0add',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftsf_28',['has_tsf',['../structuhd_1_1rfnoc_1_1tx__event__action__info.html#a7621de07341c51598b8a0954ec094ec3',1,'uhd::rfnoc::tx_event_action_info::has_tsf'],['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a05620235be16ac3b9ad1eaf0864d6627',1,'uhd::transport::vrt::if_packet_info_t::has_tsf']]],
  ['has_5ftsi_29',['has_tsi',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a9dcd8f46d3f39627945dd9d429fec8a3',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftx_5fpower_5freference_30',['has_tx_power_reference',['../classuhd_1_1rfnoc_1_1rf__control_1_1power__reference__iface.html#a3566202d0e04760394a9881e49f6c142',1,'uhd::rfnoc::rf_control::power_reference_iface::has_tx_power_reference()'],['../classuhd_1_1usrp_1_1multi__usrp.html#af5384b36f4fe1f8f90b41d8632c85ada',1,'uhd::usrp::multi_usrp::has_tx_power_reference()']]],
  ['has_5fwrite_5fcallback_31',['has_write_callback',['../classuhd_1_1experts_1_1dag__vertex__t.html#a6ff77d1929aee5558be2a68c607396aa',1,'uhd::experts::dag_vertex_t']]],
  ['have_32',['have',['../md_usrp2_2build__instructions.html#autotoc_md97',1,'What FPGA does my USRP have?'],['../md_usrp3_2build__instructions.html#autotoc_md110',1,'What FPGA does my USRP have?']]],
  ['have_20an_20equality_20operator_33',['- Must have an equality operator (==)',['../classuhd_1_1experts_1_1data__node__t.html#autotoc_md254',1,'']]],
  ['heterodyne_34',['HETERODYNE',['../classuhd_1_1usrp_1_1fe__connection__t.html#aadf0572b3c622e61053ed405327ec61fa9eed1d12ba57e1b4b6737a9f3c74513b',1,'uhd::usrp::fe_connection_t']]],
  ['hexstr_5fcast_35',['hexstr_cast',['../namespaceuhd_1_1cast.html#aa2744fe5ab41766361099fa0c9de22ce',1,'uhd::cast']]],
  ['hg_36',['HG',['../page_rdtesting.html#autotoc_md29',1,'HG'],['../page_rdtesting.html#autotoc_md32',1,'HG'],['../page_rdtesting.html#autotoc_md38',1,'HG']]],
  ['high_37',['HIGH',['../namespaceuhd_1_1usrp_1_1zbx.html#af1259db5d00c9426221fc97835c38a4ea8cbb5e15e59883ec9df14738fe49a539',1,'uhd::usrp::zbx']]],
  ['high_20level_3a_20the_20c_20api_38',['High-Level: The C API',['../page_coding.html#coding_api_hilevelc',1,'']]],
  ['high_20level_3a_20the_20multi_20usrp_39',['High-Level: The Multi-USRP',['../page_coding.html#coding_api_hilevel',1,'']]],
  ['high_20level_3a_20the_20multi_20usrp_20clock_40',['High-Level: The Multi-USRP-Clock',['../page_coding.html#coding_api_hilevelclock',1,'']]],
  ['high_20level_3a_20the_20rfnoc_20api_41',['High-Level: The RFNoC API',['../page_coding.html#coding_api_hilevel_rfnoc',1,'']]],
  ['hijack_20mode_42',['Hijack Mode',['../page_mpm.html#mpm_shell_hijack',1,'']]],
  ['hops_5fto_5fstring_43',['hops_to_string',['../classuhd_1_1rfnoc_1_1chdr_1_1mgmt__payload.html#a8fd2de17a81e6fb976e2984607e69baf',1,'uhd::rfnoc::chdr::mgmt_payload']]],
  ['host_44',['host',['../page_usrp2.html#usrp2_network_multidev',1,'Multiple devices per host'],['../page_usrp_x3x0.html#x3x0_setup_network_multidevs',1,'Multiple devices per host']]],
  ['host_20computer_45',['Host Computer',['../page_usrp_b200.html#connect_device',1,'Connect the USRP to the Host Computer'],['../page_usrp_b200.html#install_software_tools',1,'Install and Setup the Software Tools on Your Host Computer']]],
  ['host_20cpu_20data_20type_46',['The host/CPU data type',['../page_stream.html#stream_datatypes_cpu',1,'']]],
  ['host_20ethernet_20interface_47',['Installing the Host Ethernet Interface',['../page_usrp_x3x0.html#autotoc_md57',1,'']]],
  ['host_20interface_48',['host interface',['../page_usrp2.html#usrp2_network_setuphost',1,'Setup the host interface'],['../page_usrp_x3x0.html#x3x0_setup_network_host_interface',1,'Setup the host interface']]],
  ['host_20network_20traffic_49',['host network traffic',['../page_usrp2.html#usrp2_commprob_wireshark',1,'Monitor the host network traffic'],['../page_usrp_x3x0.html#x3x0_comm_issues_monitor',1,'Monitor the host network traffic']]],
  ['host_20operating_20system_50',['host operating system',['../page_usrp_e3xx.html#e310_zynq',1,'The Zynq CPU/FPGA and host operating system'],['../page_usrp_e3xx.html#e320_zynq',1,'The Zynq CPU/FPGA and host operating system']]],
  ['host_20pc_51',['Configuring your Host PC',['../page_usrp_x3x0_config.html#x3x0cfg_hostpc',1,'']]],
  ['host_20pc_20hardware_20selection_52',['Host PC Hardware Selection',['../page_usrp_x3x0_config.html#x3x0cfg_hosthw',1,'']]],
  ['host_20s_20ip_20address_53',['Configuring the host&apos;s IP address',['../page_usrp_x3x0_config.html#x3x0cfg_hostpc_netcfg_ip',1,'']]],
  ['hot_20plugging_20and_20power_20cycling_54',['Hot-Plugging and Power-Cycling',['../page_ni_rio_kernel.html#linux_swapping',1,'']]],
  ['hot_20plugging_20and_20power_20cycling_55',['Hot-plugging and Power-cycling',['../page_ni_rio_kernel.html#win_swapping',1,'']]],
  ['how_20to_20use_20the_20extension_20framework_56',['How to use the Extension Framework',['../page_extension.html#extension_howto',1,'']]],
  ['htonx_57',['htonx',['../namespaceuhd.html#ae5e5910558275e7c986e041e1f8fe1f5',1,'uhd::htonx(T)'],['../namespaceuhd.html#a7dfebe1a8443034fcc541a77afa24e31',1,'uhd::htonx(T num)']]],
  ['htowx_58',['htowx',['../namespaceuhd.html#a66d493f4be1a88fd6bb25c9914142343',1,'uhd::htowx(T)'],['../namespaceuhd.html#a0a543a320de74e9ed2fe4c51c684cf42',1,'uhd::htowx(T num)']]]
];
